@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.20";
+our $VERSION = "2.2101";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -358,7 +358,7 @@ sub fold {
 	}
 	next if $bs;
 
-	if (s/\A(\e*(?:${yield_re}(?!\cH))+)//) {
+	if (s/\A(\e+|(?:${yield_re}(?!\cH))+)//) {
 	    my $s = $1;
 	    if ((my $w = vwidth($s)) <= $room) {
 		$folded .= $s;
@@ -383,7 +383,7 @@ sub fold {
     if ($word_char_re
 	and my($w2) = /\A( (?: ${word_char_re} \cH ? ) + )/x
 	and my($lead, $w1) = $folded =~ m{
-		\A ## avoid CSI final char does not make a word
+		\A ## avoid CSI final char making a word
 		   ( (?: [^\e]* ${csi_re}++ ) *+ .*? )
 		   ( (?: ${word_char_re} \cH ? ) + )
 		\z }x
@@ -556,7 +556,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.20
+Version 2.2101
 
 =head1 SYNOPSIS
 
